.. openTEPES documentation master file, created by Andres Ramos

openTEPES Documentation
=======================

.. image:: /../imagenes/Escudo.png
   :scale: 66%
   :align: right

.. image:: /../imagenes/logoIIT.gif
   :scale: 100%
   :align: right

\ **Open** \ Generation and \ **T**\ransmission Operation and \ **E**\xpansion \ **P**\lanning Model with RES and \ **ES**\S (**openTEPES**)

“*Simplicity and Transparency in Power Systems Planning*”

The **openTEPES** model has been developed at the `Instituto de Investigación Tecnológica (IIT) <https://www.iit.comillas.edu/index.php.en>`_ of
the `Universidad Pontificia Comillas <https://www.comillas.edu/en/>`_.

Index
=====

.. toctree::
   :maxdepth: 2
   
   Introduction.rst
   InputData.rst
   OutputResults.rst
   MathematicalFormulation.rst
   Projects.rst
   Papers.rst
   Download.rst
   ContactUs.rst
